@@ -391,12 +391,33 @@ acb_get_rad_ubound_arf(arf_t u, const acb_t z, slong prec)
     arf_mul_2exp_si(u, u, 1);
 }
 
+ACB_INLINE void
+acb_union(acb_t res, const acb_t x, const acb_t y, slong prec)
+{
+    arb_union(acb_realref(res), acb_realref(x), acb_realref(y), prec);
+    arb_union(acb_imagref(res), acb_imagref(x), acb_imagref(y), prec);
+}
+
 void acb_arg(arb_t r, const acb_t z, slong prec);
 
 void acb_sgn(acb_t res, const acb_t z, slong prec);
 
 void acb_csgn(arb_t res, const acb_t z);
 
+void acb_real_abs(acb_t res, const acb_t z, int analytic, slong prec);
+void acb_real_sgn(acb_t res, const acb_t z, int analytic, slong prec);
+void acb_real_heaviside(acb_t res, const acb_t z, int analytic, slong prec);
+void acb_real_floor(acb_t res, const acb_t z, int analytic, slong prec);
+void acb_real_ceil(acb_t res, const acb_t z, int analytic, slong prec);
+void acb_real_max(acb_t res, const acb_t x, const acb_t y, int analytic, slong prec);
+void acb_real_min(acb_t res, const acb_t x, const acb_t y, int analytic, slong prec);
+void acb_real_sqrtpos(acb_t res, const acb_t z, int analytic, slong prec);
+
+void acb_sqrt_analytic(acb_t res, const acb_t z, int analytic, slong prec);
+void acb_rsqrt_analytic(acb_t res, const acb_t z, int analytic, slong prec);
+void acb_log_analytic(acb_t res, const acb_t z, int analytic, slong prec);
+void acb_pow_analytic(acb_t res, const acb_t z, const acb_t w, int analytic, slong prec);
+
 ACB_INLINE void
 acb_add(acb_t z, const acb_t x, const acb_t y, slong prec)
 {
@@ -673,6 +694,7 @@ void acb_log1p(acb_t r, const acb_t z, slong prec);
 void acb_exp(acb_t r, const acb_t z, slong prec);
 void acb_exp_pi_i(acb_t r, const acb_t z, slong prec);
 void acb_exp_invexp(acb_t r, acb_t s, const acb_t z, slong prec);
+void acb_expm1(acb_t r, const acb_t z, slong prec);
 
 void acb_sin(acb_t r, const acb_t z, slong prec);
 void acb_cos(acb_t r, const acb_t z, slong prec);
@@ -726,6 +748,24 @@ acb_coth(acb_t y, const acb_t x, slong prec)
     acb_mul_onei(y, y);
 }
 
+void acb_sech(acb_t r, const acb_t z, slong prec);
+void acb_csch(acb_t r, const acb_t z, slong prec);
+
+ACB_INLINE void
+acb_sec(acb_t y, const acb_t x, slong prec)
+{
+    acb_mul_onei(y, x);
+    acb_sech(y, y, prec);
+}
+
+ACB_INLINE void
+acb_csc(acb_t y, const acb_t x, slong prec)
+{
+    acb_mul_onei(y, x);
+    acb_csch(y, y, prec);
+    acb_mul_onei(y, y);
+}
+
 void acb_sin_pi(acb_t r, const acb_t z, slong prec);
 void acb_cos_pi(acb_t r, const acb_t z, slong prec);
 void acb_sin_cos_pi(acb_t s, acb_t c, const acb_t z, slong prec);
@@ -733,6 +773,7 @@ void acb_tan_pi(acb_t r, const acb_t z, slong prec);
 void acb_cot_pi(acb_t r, const acb_t z, slong prec);
 
 void acb_sinc(acb_t res, const acb_t z, slong prec);
+void acb_sinc_pi(acb_t res, const acb_t z, slong prec);
 
 void acb_pow_arb(acb_t z, const acb_t x, const arb_t y, slong prec);
 void acb_pow(acb_t r, const acb_t x, const acb_t y, slong prec);
@@ -782,6 +823,14 @@ void acb_polylog_si(acb_t w, slong s, const acb_t z, slong prec);
 void acb_agm1(acb_t m, const acb_t z, slong prec);
 void acb_agm1_cpx(acb_ptr m, const acb_t z, slong len, slong prec);
 
+#define ACB_LAMBERTW_LEFT 2
+#define ACB_LAMBERTW_MIDDLE 4
+
+void acb_lambertw_asymp(acb_t res, const acb_t z, const fmpz_t k, slong L, slong M, slong prec);
+int acb_lambertw_check_branch(const acb_t w, const fmpz_t k, slong prec);
+void acb_lambertw_bound_deriv(mag_t res, const acb_t z, const acb_t ez1, const fmpz_t k);
+void acb_lambertw(acb_t res, const acb_t z, const fmpz_t k, int flags, slong prec);
+
 ACB_INLINE void
 acb_sqr(acb_t res, const acb_t val, slong prec)
 {
@@ -1125,7 +1174,7 @@ void _acb_vec_sort_pretty(acb_ptr vec, slong len);
 
 /* roots of unity */
 void acb_unit_root(acb_t res, ulong order, slong prec);
-void _acb_vec_unit_roots(acb_ptr z, slong len, slong prec);
+void _acb_vec_unit_roots(acb_ptr z, slong order, slong len, slong prec);
 
 ACB_INLINE slong
 acb_allocated_bytes(const acb_t x)
