@@ -297,11 +297,11 @@ arb_get_abs_lbound_arf(arf_t u, const arb_t x, slong prec)
 
     if (arf_sgn(arb_midref(x)) > 0)
     {
-        arf_sub(u, arb_midref(x), t, prec, ARF_RND_UP);
+        arf_sub(u, arb_midref(x), t, prec, ARF_RND_DOWN);
     }
     else
     {
-        arf_add(u, arb_midref(x), t, prec, ARF_RND_UP);
+        arf_add(u, arb_midref(x), t, prec, ARF_RND_DOWN);
         arf_neg(u, u);
     }
 
@@ -327,6 +327,8 @@ arb_get_lbound_arf(arf_t u, const arb_t x, long prec)
     arf_sub(u, arb_midref(x), t, prec, ARF_RND_FLOOR);
 }
 
+void arb_nonnegative_part(arb_t res, const arb_t x);
+
 slong arb_rel_error_bits(const arb_t x);
 
 ARB_INLINE slong
@@ -395,6 +397,9 @@ void arb_set_interval_mpfr(arb_t x, const mpfr_t a, const mpfr_t b, slong prec);
 void arb_get_interval_arf(arf_t a, arf_t b, const arb_t x, slong prec);
 void arb_get_interval_mpfr(mpfr_t a, mpfr_t b, const arb_t x);
 
+void arb_set_interval_mag(arb_t res, const mag_t a, const mag_t b, slong prec);
+void arb_set_interval_neg_pos_mag(arb_t res, const mag_t a, const mag_t b, slong prec);
+
 void arb_union(arb_t z, const arb_t x, const arb_t y, slong prec);
 int arb_intersection(arb_t z, const arb_t x, const arb_t y, slong prec);
 void arb_get_rand_fmpq(fmpq_t q, flint_rand_t state, const arb_t x, slong bits);
@@ -485,6 +490,7 @@ void arb_log_ui(arb_t z, ulong x, slong prec);
 void arb_log_fmpz(arb_t z, const fmpz_t x, slong prec);
 void arb_log1p(arb_t r, const arb_t z, slong prec);
 void arb_log_base_ui(arb_t res, const arb_t x, ulong b, slong prec);
+void arb_log_hypot(arb_t res, const arb_t x, const arb_t y, slong prec);
 void arb_exp(arb_t z, const arb_t x, slong prec);
 void arb_expm1(arb_t z, const arb_t x, slong prec);
 void arb_exp_invexp(arb_t z, arb_t w, const arb_t x, slong prec);
@@ -505,6 +511,7 @@ void arb_sin_cos_pi_fmpq(arb_t s, arb_t c, const fmpq_t x, slong prec);
 void arb_sin_pi_fmpq(arb_t s, const fmpq_t x, slong prec);
 void arb_cos_pi_fmpq(arb_t c, const fmpq_t x, slong prec);
 void arb_sinc(arb_t z, const arb_t x, slong prec);
+void arb_sinc_pi(arb_t z, const arb_t x, slong prec);
 void arb_sinh(arb_t z, const arb_t x, slong prec);
 void arb_cosh(arb_t z, const arb_t x, slong prec);
 void arb_sinh_cosh(arb_t s, arb_t c, const arb_t x, slong prec);
@@ -518,6 +525,12 @@ void arb_acos(arb_t z, const arb_t x, slong prec);
 void arb_atanh(arb_t z, const arb_t x, slong prec);
 void arb_asinh(arb_t z, const arb_t x, slong prec);
 void arb_acosh(arb_t z, const arb_t x, slong prec);
+
+void arb_sec(arb_t res, const arb_t x, slong prec);
+void arb_csc(arb_t res, const arb_t x, slong prec);
+void arb_sech(arb_t res, const arb_t x, slong prec);
+void arb_csch(arb_t res, const arb_t x, slong prec);
+
 void arb_fac_ui(arb_t z, ulong n, slong prec);
 void arb_doublefac_ui(arb_t z, ulong n, slong prec);
 void arb_bin_ui(arb_t z, const arb_t n, ulong k, slong prec);
@@ -586,6 +599,7 @@ void arb_power_sum_vec(arb_ptr res, const arb_t a, const arb_t b, slong len, slo
 void arb_bell_sum_taylor(arb_t res, const fmpz_t n, const fmpz_t a, const fmpz_t b, const fmpz_t mmag, slong prec);
 void arb_bell_sum_bsplit(arb_t res, const fmpz_t n, const fmpz_t a, const fmpz_t b, const fmpz_t mmag, slong prec);
 void arb_bell_fmpz(arb_t res, const fmpz_t n, slong prec);
+void arb_bell_ui(arb_t res, ulong n, slong prec);
 
 void arb_euler_number_fmpz(arb_t res, const fmpz_t n, slong prec);
 void arb_euler_number_ui(arb_t res, ulong n, slong prec);
@@ -593,6 +607,8 @@ void arb_euler_number_ui(arb_t res, ulong n, slong prec);
 void arb_partitions_fmpz(arb_t res, const fmpz_t n, slong prec);
 void arb_partitions_ui(arb_t res, ulong n, slong prec);
 
+void arb_lambertw(arb_t res, const arb_t x, int flags, slong prec);
+
 ARB_INLINE void
 arb_sqr(arb_t res, const arb_t val, slong prec)
 {
@@ -932,6 +948,7 @@ void _arb_exp_taylor_rs(mp_ptr y, mp_limb_t * error,
     mp_srcptr x, mp_size_t xn, ulong N);
 
 void arb_exp_arf_bb(arb_t z, const arf_t x, slong prec, int minus_one);
+void arb_exp_arf_rs_generic(arb_t res, const arf_t x, slong prec, int minus_one);
 
 int _arb_get_mpn_fixed_mod_log2(mp_ptr w, fmpz_t q, mp_limb_t * error,
                                                 const arf_t x, mp_size_t wn);
@@ -977,6 +994,10 @@ void _arb_sin_cos_taylor_rs(mp_ptr ysin, mp_ptr ycos,
 int _arb_get_mpn_fixed_mod_pi4(mp_ptr w, fmpz_t q, int * octant,
     mp_limb_t * error, const arf_t x, mp_size_t wn);
 
+void arb_sin_cos_arf_bb(arb_t zsin, arb_t zcos, const arf_t x, slong prec);
+void arb_sin_cos_arf_rs_generic(arb_t res_sin, arb_t res_cos, const arf_t x, slong prec);
+void arb_sin_cos_arf_generic(arb_t res_sin, arb_t res_cos, const arf_t x, slong prec);
+
 ARB_INLINE mp_bitcnt_t
 _arb_mpn_leading_zeros(mp_srcptr d, mp_size_t n)
 {
